@@ -34,8 +34,11 @@ def _get_kwargs(
     provides: Union[Unset, None, str] = UNSET,
     purl: Union[Unset, None, str] = UNSET,
     re_name: Union[Unset, None, str] = UNSET,
+    re_provides: Union[Unset, None, str] = UNSET,
     re_purl: Union[Unset, None, str] = UNSET,
-    re_upstream: Union[Unset, None, str] = UNSET,
+    re_sources: Union[Unset, None, str] = UNSET,
+    re_upstreams: Union[Unset, None, str] = UNSET,
+    related_url: Union[Unset, None, str] = UNSET,
     release: Union[Unset, None, str] = UNSET,
     search: Union[Unset, None, str] = UNSET,
     sources: Union[Unset, None, str] = UNSET,
@@ -100,8 +103,11 @@ def _get_kwargs(
         "provides": provides,
         "purl": purl,
         "re_name": re_name,
+        "re_provides": re_provides,
         "re_purl": re_purl,
-        "re_upstream": re_upstream,
+        "re_sources": re_sources,
+        "re_upstreams": re_upstreams,
+        "related_url": related_url,
         "release": release,
         "search": search,
         "sources": sources,
@@ -167,8 +173,11 @@ def sync_detailed(
     provides: Union[Unset, None, str] = UNSET,
     purl: Union[Unset, None, str] = UNSET,
     re_name: Union[Unset, None, str] = UNSET,
+    re_provides: Union[Unset, None, str] = UNSET,
     re_purl: Union[Unset, None, str] = UNSET,
-    re_upstream: Union[Unset, None, str] = UNSET,
+    re_sources: Union[Unset, None, str] = UNSET,
+    re_upstreams: Union[Unset, None, str] = UNSET,
+    related_url: Union[Unset, None, str] = UNSET,
     release: Union[Unset, None, str] = UNSET,
     search: Union[Unset, None, str] = UNSET,
     sources: Union[Unset, None, str] = UNSET,
@@ -202,8 +211,11 @@ def sync_detailed(
         provides=provides,
         purl=purl,
         re_name=re_name,
+        re_provides=re_provides,
         re_purl=re_purl,
-        re_upstream=re_upstream,
+        re_sources=re_sources,
+        re_upstreams=re_upstreams,
+        related_url=related_url,
         release=release,
         search=search,
         sources=sources,
@@ -250,8 +262,11 @@ def sync(
     provides: Union[Unset, None, str] = UNSET,
     purl: Union[Unset, None, str] = UNSET,
     re_name: Union[Unset, None, str] = UNSET,
+    re_provides: Union[Unset, None, str] = UNSET,
     re_purl: Union[Unset, None, str] = UNSET,
-    re_upstream: Union[Unset, None, str] = UNSET,
+    re_sources: Union[Unset, None, str] = UNSET,
+    re_upstreams: Union[Unset, None, str] = UNSET,
+    related_url: Union[Unset, None, str] = UNSET,
     release: Union[Unset, None, str] = UNSET,
     search: Union[Unset, None, str] = UNSET,
     sources: Union[Unset, None, str] = UNSET,
@@ -287,8 +302,11 @@ def sync(
         provides=provides,
         purl=purl,
         re_name=re_name,
+        re_provides=re_provides,
         re_purl=re_purl,
-        re_upstream=re_upstream,
+        re_sources=re_sources,
+        re_upstreams=re_upstreams,
+        related_url=related_url,
         release=release,
         search=search,
         sources=sources,
@@ -323,8 +341,11 @@ QUERY_PARAMS = {
     "provides": str,
     "purl": str,
     "re_name": str,
+    "re_provides": str,
     "re_purl": str,
-    "re_upstream": str,
+    "re_sources": str,
+    "re_upstreams": str,
+    "related_url": str,
     "release": str,
     "search": str,
     "sources": str,
